==> color-1.0.2.tgz: package/lib/tests/index.test.js <==
"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _color = _interopRequireDefault(require("color"));

var _index = _interopRequireWildcard(require("../index"));

describe('ColorWrapper', function () {
  it('should be the ColorMock class', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color instanceof _index.ColorMock).toBe(true);
  });
  it('should be the same color', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color.darken().toString()).toEqual('linear-gradient(#FFF, #000)');
  });
  it('should use toString and have equal value', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color.darken().toString()).toEqual(color.toString());
  });
  it('should use toString after N pipe and have equal value', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color.darken().rgb().lighten().toString()).toEqual(color.toString());
  });
  it('should use the real Color', function () {
    var color = (0, _index.default)('#f00');
    var color2 = (0, _color.default)('#f00');
    expect(color.darken(0.5).toString()).toEqual(color2.darken(0.5).toString());
  });
  it('should use the real Color', function () {
    var color = (0, _index.default)('#f00');
    var color2 = (0, _color.default)('#f00');
    expect(color.darken(0.5).toString()).toEqual(color2.darken(0.5).toString());
  });
});

==> color-1.0.3.tgz: package/lib/tests/index.test.js <==
"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _color = _interopRequireDefault(require("color"));

var _index = _interopRequireWildcard(require("../index"));

describe('ColorWrapper', function () {
  it('should be the ColorMock class', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color instanceof _index.ColorMock).toBe(true);
  });
  it('should be the same color', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color.darken().toString()).toEqual('linear-gradient(#FFF, #000)');
  });
  it('should use toString and have equal value', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color.darken().toString()).toEqual(color.toString());
  });
  it('should use toString after N pipe and have equal value', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color.darken().lighten().darken().toString()).toEqual(color.toString());
  });
  it('should end with a string when calling .rgb()', function () {
    var color = (0, _index.default)('linear-gradient(#FFF, #000)');
    expect(color.rgb()).toEqual(color.toString());
  });
  it('should use the real Color', function () {
    var color = (0, _index.default)('#f00');
    var color2 = (0, _color.default)('#f00');
    expect(color.darken(0.5).toString()).toEqual(color2.darken(0.5).toString());
  });
  it('should use the real Color', function () {
    var color = (0, _index.default)('#f00');
    var color2 = (0, _color.default)('#f00');
    expect(color.darken(0.5).toString()).toEqual(color2.darken(0.5).toString());
  });
  it('should use the real Color', function () {
    var color = (0, _index.default)('#f00');
    var color2 = (0, _color.default)('#f00');
    expect(color.darken(0.5).toString()).toEqual(color2.darken(0.5).toString());
  });
});
